# eric7.Preferences.ConfigurationPages

Package implementing the various pages of the configuration dialog.

### Modules

ApplicationPage | Module implementing the Application configuration page.
CondaPage | Module implementing the conda configuration page.
ConfigurationPageBase | Module implementing the base class for all configuration pages.
CooperationPage | Module implementing the Cooperation configuration page.
DebuggerGeneralPage | Module implementing the Debugger General configuration page.
DebuggerPython3Page | Module implementing the Debugger Python3 configuration page.
DiffColoursPage | Module implementing the Diff colours configuration page.
EditorAPIsPage | Module implementing the Editor APIs configuration page.
EditorAutoCompletionJediPage | Module implementing the Jedi Auto-completion configuration page.
EditorAutocompletionPage | Module implementing the Editor Autocompletion configuration page.
EditorAutocompletionQScintillaPage | Module implementing the QScintilla Autocompletion configuration page.
EditorCallTipsJediPage | Module implementing the Jedi Calltips configuration page.
EditorCalltipsPage | Module implementing the Editor Calltips configuration page.
EditorCalltipsQScintillaPage | Module implementing the QScintilla Calltips configuration page.
EditorDocViewerPage | Module implementing the Editor Documentation Viewer configuration page.
EditorExportersPage | Module implementing the Editor Exporters configuration page.
EditorFilePage | Module implementing the Editor File Handling configuration page.
EditorGeneralPage | Module implementing the Editor General configuration page.
EditorHighlightersPage | Module implementing the Editor Highlighter Associations configuration page.
EditorHighlightingStylesPage | Module implementing the Editor Highlighting Styles configuration page.
EditorHighlightingStylesSelectionDialog | Module implementing a dialog to select the styles to be imported/exported.
EditorKeywordsPage | Module implementing the editor highlighter keywords configuration page.
EditorLanguageTabIndentOverrideDialog | Module implementing a dialog to set the tab and indentation width override for a language.
EditorMouseClickHandlerJediPage | Module implementing the Jedi Mouse Click Handler configuration page.
EditorMouseClickHandlerPage | Module implementing the Editor Mouse Click Handlers configuration page.
EditorPropertiesPage | Module implementing the Editor Properties configuration page.
EditorSearchPage | Module implementing the Editor Search configuration page.
EditorSpellCheckingPage | Module implementing the Editor Spellchecking configuration page.
EditorStylesPage | Module implementing the Editor Styles configuration page.
EditorSyntaxPage | Module implementing the Editor Syntax Checker configuration page.
EditorTypingPage | Module implementing the Editor Typing configuration page.
EmailPage | Module implementing the Email configuration page.
EricServerPage | Module implementing the eric-ide server related settings.
GraphicsPage | Module implementing the Printer configuration page.
HelpDocumentationPage | Module implementing the Help Documentation configuration page.
HelpViewersPage | Module implementing the Help Viewers configuration page.
HexEditorPage | Module implementing the Hex Editor configuration page.
IconsPage | Module implementing the Icons configuration page.
IconsPreviewDialog | Module implementing a dialog to preview the contents of an icon directory.
InterfaceLightPage | Module implementing the Interface configuration page (variant for web browser).
InterfacePage | Module implementing the Interface configuration page.
IrcPage | Module implementing the IRC configuration page.
LogViewerPage | Module implementing the Log Viewer configuration page.
MainPasswordEntryDialog | Module implementing a dialog to enter or change the main password.
MicroPythonPage | Module implementing the MicroPython configuration page.
MimeTypesPage | Module implementing the Text Mime Types configuration page.
MultiProjectPage | Module implementing the Multi Project configuration page.
NetworkPage | Module implementing the Network configuration page.
NetworkProxyPage | Module implementing the Network configuration page.
NotificationsPage | Module implementing the Notifications configuration page.
PdfViewerPage | Module implementing the PDF Viewer configuration page.
PipPage | Module implementing the pip configuration page.
PluginManagerPage | Module implementing the Plugin Manager configuration page.
PrinterPage | Module implementing the Printer configuration page.
ProjectBrowserPage | Module implementing the Project Browser configuration page.
ProjectPage | Module implementing the Project configuration page.
PythonPage | Module implementing the Python configuration page.
QtPage | Module implementing the Qt configuration page.
SecurityPage | Module implementing the Security configuration page.
ShellPage | Module implementing the Shell configuration page.
TasksPage | Module implementing the Tasks configuration page.
TemplatesPage | Module implementing the Templates configuration page.
TrayStarterPage | Module implementing the tray starter configuration page.
VcsPage | Module implementing the VCS configuration page.
ViewmanagerPage | Module implementing the Viewmanager configuration page.
WebBrowserAppearancePage | Module implementing the Web Browser Appearance configuration page.
WebBrowserPage | Module implementing the Web Browser configuration page.
WebBrowserSpellCheckingPage | Module implementing the Web Browser Spell Checking configuration page.
WebBrowserVirusTotalPage | Module implementing VirusTotal configuration page (web browser variant).